============
Installation
============

At the command line::

    $ pip install os-brick

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv os-brick
    $ pip install os-brick

Or, from source::

    $ git clone https://github.com/openstack/os-brick
    $ cd os-brick
    $ python setup.py install
